@@ -3,7 +3,7 @@
 # Business::Bitcoin::Request - Bitcoin payment request
 # Copyright (c) 2016-2017 Ashish Gulhati <biz-btc at hash dot neomailbox.ch>
 #
-# $Id: lib/Business/Bitcoin/Request.pm v1.036 Sun Apr  2 10:12:41 PDT 2017 $
+# $Id: lib/Business/Bitcoin/Request.pm v1.037 Tue Apr 18 23:22:21 PDT 2017 $
 
 use warnings;
 use strict;
@@ -21,7 +21,7 @@ use Crypt::RIPEMD160;
 
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.036 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.037 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my ($class, %args) = @_;
@@ -93,10 +93,12 @@ sub _getaddress {
   my ($ver, $depth, $fp, $i, $c, $Kc) = ($1, $2, $3, $4, $5, $6);
   my $K = Math::EllipticCurve::Prime::Point->from_hex(_decompress($Kc));
   # m/0
-  my ($Ki, $ci) = _CKDpub($K, $c, 0);
+  # my ($Ki, $ci) = _CKDpub($K, $c, 0);
   # m/0/$index
-  my ($Ki2, $ci2) = _CKDpub($Ki, $ci, $index);
-  return _address(_compress($Ki2));
+  # my ($Ki2, $ci2) = _CKDpub($Ki, $ci, $index);
+  # return _address(_compress($Ki2));
+  my ($Ki, $ci) = _CKDpub($K, $c, $index);
+  return _address(_compress($Ki));
 }
 
 sub _CKDpub {
@@ -131,6 +133,7 @@ sub _decompress {
 sub _compress {
   my $K = shift;
   my $Kc = $K->x->as_hex; $Kc =~ s/^0x//;
+  $Kc = '0' x (64 - length($Kc)) . $Kc;
   $Kc = ($K->y % 2 ? '03' : '02') . $Kc;
 }
 
@@ -171,8 +174,8 @@ Business::Bitcoin::Request - Bitcoin payment request
 
 =head1 VERSION
 
- $Revision: 1.036 $
- $Date: Sun Apr  2 10:12:41 PDT 2017 $
+ $Revision: 1.037 $
+ $Date: Tue Apr 18 23:22:21 PDT 2017 $
 
 =head1 SYNOPSIS
 
@@ -295,7 +298,7 @@ L<http://search.cpan.org/dist/Business-Bitcoin/>
 Copyright (c) 2016-2017 Ashish Gulhati.
 
 This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+under the terms of the Artistic License 2.0.
 
-See http://dev.perl.org/licenses/ for more information.
+See L<http://www.perlfoundation.org/artistic_license_2_0> for the full
+license terms.
